@@ -45,7 +45,7 @@ class BlogIndexView(MetaSidebar, ListView):
         context = super(BlogIndexView, self).get_context_data(**kwargs)
         context.update({
             'title': _('Blog'),
-            'description': conf.SITE_DESCRIPTION,
+            'description': _('This is the blog'),
         })
         return context
 
@@ -63,22 +63,25 @@ class PostDetailView(MetaSidebar, DetailView):
         current_site = get_current_site(self.request)
         current_url = reverse('app_blog-post-detail', kwargs={'slug': self.kwargs['slug']})
         # Si esta activado DISQUS_SYNC rellenamos el thread_id vía API
-        if conf.DISQUS_SYNC:
-            if not self.obj.thread_id:
-                try:
-                    #print 'link:http://'+current_site.domain+current_url
-                    api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
-                    dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:http://'+current_site.domain+current_url)
-                    self.obj.thread_id = dq_response['id']
-                except:
-                    pass
-                try:
-                    #print 'link:http://www.'+current_site.domain+current_url
-                    api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
-                    dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:http://www.'+current_site.domain+current_url)
-                    self.obj.thread_id = dq_response['id']
-                except:
-                    pass
+        try:
+            if conf.DISQUS_SYNC:
+                if not self.obj.thread_id:
+                    try:
+                        #print 'link:http://'+current_site.domain+current_url
+                        api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
+                        dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:http://'+current_site.domain+current_url)
+                        self.obj.thread_id = dq_response['id']
+                    except:
+                        pass
+                    try:
+                        #print 'link:http://www.'+current_site.domain+current_url
+                        api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
+                        dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:http://www.'+current_site.domain+current_url)
+                        self.obj.thread_id = dq_response['id']
+                    except:
+                        pass
+        except:
+            pass
         self.obj.save()
         return self.obj
 
@@ -86,7 +89,6 @@ class PostDetailView(MetaSidebar, DetailView):
         context = super(PostDetailView, self).get_context_data(**kwargs)
         comments = mymodels.Comments.objects.filter(thread_id=self.obj.thread_id)
         context.update({
-            'title': self.obj.title,
             'comments': comments,
         })
         return context
